*********************************************************************************************************************************
* Meyer/Schoen 2014, Response Latencies and Attitude-Behavior Consistency in a Direct Democratic Setting:
* Evidence from a Subnational Referendum in Germany, in Political Psychology 35, 431-440.
*
* SPSS & Stata-Syntax for replication purposes
*
* Data: Survey conducted before and after the referendum on nonsmoking policy in Bavaria (see Gesis, ZA5363)
*
*********************************************************************************************************************************
**********************************************************************************************************************
**********************************************************************************************************************
*** Basic data modifications
* Time variables originally in time format, creating new 'n' variables in numeric time format
* Thus, first extracting minutes * 60 + extracting seconds
GET FILE='C:\...\Volksentscheid_VV+NV.sav'.
COMPUTE ZQ04n=xdate.minute(ZQ04)*60+xdate.second(ZQ04).
COMPUTE ZQ05n=xdate.minute(ZQ05)*60+xdate.second(ZQ05).
COMPUTE ZQ13_1n=xdate.minute(ZQ13_1)*60+xdate.second(ZQ13_1).
COMPUTE ZQ13_2n=xdate.minute(ZQ13_2)*60+xdate.second(ZQ13_2).
COMPUTE ZQ13_3n=xdate.minute(ZQ13_3)*60+xdate.second(ZQ13_3).
COMPUTE ZQ13_4n=xdate.minute(ZQ13_4)*60+xdate.second(ZQ13_4).
COMPUTE ZQ13_5n=xdate.minute(ZQ13_5)*60+xdate.second(ZQ13_5).
COMPUTE ZQ13_6n=xdate.minute(ZQ13_6)*60+xdate.second(ZQ13_6).
COMPUTE ZQ13_7n=xdate.minute(ZQ13_7)*60+xdate.second(ZQ13_7).
COMPUTE ZQ13_8n=xdate.minute(ZQ13_8)*60+xdate.second(ZQ13_8).
COMPUTE ZQ13_9n=xdate.minute(ZQ13_9)*60+xdate.second(ZQ13_9).
COMPUTE ZQ13_10n=xdate.minute(ZQ13_10)*60+xdate.second(ZQ13_10).
COMPUTE ZQ24n=xdate.minute(ZQ24)*60+xdate.second(ZQ24).
COMPUTE ZQ64n=xdate.minute(ZQ64)*60+xdate.second(ZQ64).
COMPUTE ZQ65n=xdate.minute(ZQ65)*60+xdate.second(ZQ65).
COMPUTE ZQ74n=xdate.minute(ZQ74)*60+xdate.second(ZQ74).
COMPUTE ZQ75n=xdate.minute(ZQ75)*60+xdate.second(ZQ75).
COMPUTE ZQ76n=xdate.minute(ZQ76)*60+xdate.second(ZQ76).
COMPUTE ZQ77n=xdate.minute(ZQ77)*60+xdate.second(ZQ77).
COMPUTE ZQ78n=xdate.minute(ZQ78)*60+xdate.second(ZQ78).
COMPUTE ZQ79n=xdate.minute(ZQ79)*60+xdate.second(ZQ79).
*** Creating common time variables from questionnaire splits
* Time variable for party identification (Bavaria vs. Germany)
if split=1 zpid=zq64n.
if split=2 zpid=zq65n.
exec.
* Anger or Enlightment (concerning non-smoking in pubs) if referendum is succesfull
recode zq78n (low thru high=1) (else=sysmis) into zq78help.
recode zq74n (low thru high=1) (else=sysmis) into zq74help.
fre zq78help zq74help /format notable.
if zq78help=1 zpub=zq78n.
if zq74help=1 zpub=zq74n.
exec.
* Fear Cancer, active or passive smoking
recode zq76n (low thru high=1) (else=sysmis) into zq76help.
recode zq79n (low thru high=1) (else=sysmis) into zq79help.
if zq76help=1 zcancer=zq76n.
if zq79help=1 zcancer=zq79n.
exec.
*** Creating control variables
* Political interest
recode Q01 (1=5) (2=4) (3=3) (4=2) (5=1) (else=sysmis) into polint.
* civic duty
mis val Q20_07 (6 7).
compute civic_duty=6-Q20_07.
* issue importance
recode Q10 (1=5) (2=4) (3=3) (4=2) (5=1) (else=sysmis) into importance.
* knowledge
recode Q03 (1=1) (else=0) into know_date.
recode Q12_01 (1=1) (else=0) into beertent.
recode Q12_02 (2=1) (1 3 4=0) into jail.
recode Q12_03 (2=1) (1 3=0) into hospital.
recode Q12_04 (2=1) (1 3 4=0) into barowner.
recode Q12_05 (2=1) (1 3 4=0) into prevent.
compute knowledge=beertent+jail+hospital+barowner+prevent+know_date.
* Smoker
recode Q69 (1=1) (2=0) (else=sysmis) into smoker.
* Education
recode Q57 (1 2 6 8 9 =1) (else=0) into educ_low.
recode Q57 (4 5=1) (else=0) into educ_high.
* Age
mis val Q55 (9999).
compute age=2010-Q55.
* Saving this data, which serve as base version for all operationalization Variants, respectively
save outfile='C:\...\Volksentscheid_base.sav'.
**********************************************************************************************************************
**********************************************************************************************************************
*** Turnout intention, Variant A
* Keep only panel respondents
recode ndatum (100705 thru 100719=1) (else=0) into panel.
sel if panel=1.
* Exclude extreme outliers (reaction times over one minute)
recode zq04n zq13_1n zq13_2n zq13_3n zq13_4n zq13_5n zq13_6n zq13_7n zq13_8n zq13_9n zq13_10n zq24n zpid zpub zcancer (60.01 thru high = 9999) (else=copy).
sel if zq04n <> 9999.
sel if zq13_1n <> 9999.
sel if zq13_2n <> 9999.
sel if zq13_3n <> 9999.
sel if zq13_4n <> 9999.
sel if zq13_5n <> 9999.
sel if zq13_6n <> 9999.
sel if zq13_7n <> 9999.
sel if zq13_8n <> 9999.
sel if zq13_9n <> 9999.
sel if zq13_10n <> 9999.
sel if zq24n <> 9999.
sel if zpid <> 9999.
sel if zpub <> 9999.
sel if zcancer <> 9999.
* Calculate means and SDs
fre zq04n zq13_1n zq13_2n zq13_3n zq13_4n zq13_5n zq13_6n zq13_7n zq13_8n zq13_9n zq13_10n zq24n zpid zpub zcancer /sta mean stddev /format notable.
* Upper limit:
*zq04n: 12.62
*zq13_1n: 21.01
*zq13_2n: 19.16
*zq13_3n: 18.44
*zq13_4n: 10.43
*zq13_5n: 23.33
*zq13_6n: 16.67
*zq13_7n: 22.39
*zq13_8n: 15.83
*zq13_9n: 15.62
*zq13_10n: 19.17
*zq24n: 25.19
*zpid: 19.84
*zpub: 15.70
*zcancer: 12.80
* Define valid range, +/- 2 SDs from MEAN (+ 0.01 for upper limit)0,01)
recode zq04n (12.63 thru high=9999) (else=copy) into zq04h.
recode zq13_1n (21.02 thru high=9999) (else=copy) into zq13_1h.
recode zq13_2n (19.17 thru high=9999) (else=copy) into zq13_2h.
recode zq13_3n (18.45 thru high=9999) (else=copy) into zq13_3h.
recode zq13_4n (10.44 thru high=9999) (else=copy) into zq13_4h.
recode zq13_5n (23.34 thru high=9999) (else=copy) into zq13_5h.
recode zq13_6n (16.68 thru high=9999) (else=copy) into zq13_6h.
recode zq13_7n (22.40 thru high=9999) (else=copy) into zq13_7h.
recode zq13_8n (15.84 thru high=9999) (else=copy) into zq13_8h.
recode zq13_9n (15.63 thru high=9999) (else=copy) into zq13_9h.
recode zq13_10n (19.18 thru high=9999) (else=copy) into zq13_10h.
recode zq24n (25.20 thru high=9999) (else=copy) into zq24h.
recode zpid (19.85 thru high=9999) (else=copy) into zpidh.
recode zpub (15.71 thru high=9999) (else=copy) into zpubh.
recode zcancer(12.81 thru high=9999) (else=copy) into zcancerh.
* Drop those invalid times for dependent variable
sel if zq04h <> 9999.
**** Construction of baseline speed
*Count missing values for filler latencies and drop if more than 6 missing values
count count_missing= zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh (9999).
recode count_missing (0 thru 6=0) (else=1) into number_missing.
sel if number_missing <> 1.
mis val zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh (9999).
fre zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh /sta range mean median skew stddev /format notable.
*** From now: Weighting active because e.g. Age, education might be correlated with reaction time
weight by npersgew.
* Construction of baseline speed with additive index (mean imputation)
compute basis=MEAN(zq13_1h, zq13_2h, zq13_3h, zq13_4h, zq13_5h, zq13_6h, zq13_7h, zq13_8h, zq13_9h, zq13_10h, zq24h, zpidh, zpubh, zcancerh).
* Descriptive statistics
fre basis zq04h /sta min max range mean median skew stddev /format notable.
corr zq04h with basis.
* Residual-Index
reg /dep=zq04h /enter=basis /residuals /save resid.
fre RES_1 /sta=mean median range skew stddev /format notable.
* Splitting Residual-Index at median, short vs. long response latency
if RES_1 > -0.53 srl=0.
if RES_1 <= -0.53 srl=1.
fre srl.
*** Create turnout, turnout intention and interactions with srl
* Reported turnout
recode N02 (1=1) (2=0) (else=sysmis) into turnout.
* Turnout intention (Operationalization 1: residual answers (don't know & NA) are included and treated as unsure, perhaps-answers)
recode Q04 (1=1) (else=0) into definitely.
recode Q04 (2=1) (else=0) into probably.
recode Q04 (3 7 8=1) (else=0) into perhaps.
recode Q04 (4=1) (else=0) into probably_not.
recode Q04 (5=1) (else=0) into definitely_not.
* Interactions with srl
compute definitely_srl=definitely*srl.
compute probably_srl=probably*srl.
compute perhaps_srl=perhaps*srl.
compute probably_not_srl=probably_not*srl.
compute definitely_not_srl=definitely_not*srl.
*** Operationalization 2 (only perhaps-respondents included, don't knows & NA excluded from analysis)
*Turnout intention
recode Q04 (1=1) (2 thru 5=0) (else=sysmis) into definitelya.
recode Q04 (2=1) (1 3 4 5=0) (else=sysmis) into probablya.
recode Q04 (3=1) (1 2 4 5=0) (else=sysmis) into perhapsa.
recode Q04 (4=1) (1 2 3 5=0) (else=sysmis) into probably_nota.
recode Q04 (5=1) (1 thru 4=0) (else=sysmis) into definitely_nota.
* Interactions with srl
compute definitelya_srl=definitelya*srl.
compute probablya_srl=probablya*srl.
compute perhapsa_srl=perhapsa*srl.
compute probably_nota_srl=probably_nota*srl.
compute definitely_nota_srl=definitely_nota*srl.
exec.
*** Saving these modifications as Stata-file for a simpler estimation of robust standard errors and predicted probabilities
SAVE TRANSLATE OUTFILE='C:\...\stata_turnoutA.dta'
/TYPE=STATA
/VERSION=8
/EDITION=SE
/MAP
/REPLACE.
***************************************************************************************************************************************
*** Stata syntax (using SPost ado package for predictions, see Long, Scott J. / Freese, Jeremy, 2005: Regression Models for Categorical Outcomes Using Stata. Second Edition. College Station, TX: Stata Press.)
*** Logit models with and without latencies (Operationalization Variant 1)
logit turnout definitely probably probably_not definitely_not polint civic_duty importance knowledge smoker educ_low educ_high age [pweight=Npersgew]
logit turnout definitely probably probably_not definitely_not definitely_srl probably_srl probably_not_srl definitely_not_srl srl polint civic_duty importance knowledge smoker educ_low educ_high age [pweight=Npersgew]
*predicted probabilities for slow answers (using SPost ado package, Long/Freese 2005)
prvalue, x(definitely=1 probably=0 probably_not=0 definitely_not=0 definitely_srl=0 probably_srl=0 probably_not_srl=0 definitely_not_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitely=0 probably=1 probably_not=0 definitely_not=0 definitely_srl=0 probably_srl=0 probably_not_srl=0 definitely_not_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitely=0 probably=0 probably_not=0 definitely_not=0 definitely_srl=0 probably_srl=0 probably_not_srl=0 definitely_not_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitely=0 probably=0 probably_not=1 definitely_not=0 definitely_srl=0 probably_srl=0 probably_not_srl=0 definitely_not_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitely=0 probably=0 probably_not=0 definitely_not=1 definitely_srl=0 probably_srl=0 probably_not_srl=0 definitely_not_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
*predicted probabilities for fast answers
prvalue, x(definitely=1 probably=0 probably_not=0 definitely_not=0 definitely_srl=1 probably_srl=0 probably_not_srl=0 definitely_not_srl=0 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitely=0 probably=1 probably_not=0 definitely_not=0 definitely_srl=0 probably_srl=1 probably_not_srl=0 definitely_not_srl=0 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitely=0 probably=0 probably_not=0 definitely_not=0 definitely_srl=0 probably_srl=0 probably_not_srl=0 definitely_not_srl=0 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitely=0 probably=0 probably_not=1 definitely_not=0 definitely_srl=0 probably_srl=0 probably_not_srl=1 definitely_not_srl=0 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitely=0 probably=0 probably_not=0 definitely_not=1 definitely_srl=0 probably_srl=0 probably_not_srl=0 definitely_not_srl=1 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
*Logit models with and without latencies (Operationalization Variant 2)
logit turnout definitelya probablya probably_nota definitely_nota polint civic_duty importance knowledge smoker educ_low educ_high age [pweight=Npersgew]
logit turnout definitelya probablya probably_nota definitely_nota definitelya_srl probablya_srl probably_nota_srl definitely_nota_srl srl polint civic_duty importance knowledge smoker educ_low educ_high age [pweight=Npersgew]
* Predicted probabilities for slow answers
prvalue, x(definitelya=1 probablya=0 probably_nota=0 definitely_nota=0 definitelya_srl=0 probablya_srl=0 probably_nota_srl=0 definitely_nota_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitelya=0 probablya=1 probably_nota=0 definitely_nota=0 definitelya_srl=0 probablya_srl=0 probably_nota_srl=0 definitely_nota_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitelya=0 probablya=0 probably_nota=0 definitely_nota=0 definitelya_srl=0 probablya_srl=0 probably_nota_srl=0 definitely_nota_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitelya=0 probablya=0 probably_nota=1 definitely_nota=0 definitelya_srl=0 probablya_srl=0 probably_nota_srl=0 definitely_nota_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitelya=0 probablya=0 probably_nota=0 definitely_nota=1 definitelya_srl=0 probablya_srl=0 probably_nota_srl=0 definitely_nota_srl=0 srl=0 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
* Predicted probabilities for fast answers
prvalue, x(definitelya=1 probablya=0 probably_nota=0 definitely_nota=0 definitelya_srl=1 probablya_srl=0 probably_nota_srl=0 definitely_nota_srl=0 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitelya=0 probablya=1 probably_nota=0 definitely_nota=0 definitelya_srl=0 probablya_srl=1 probably_nota_srl=0 definitely_nota_srl=0 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitelya=0 probablya=0 probably_nota=0 definitely_nota=0 definitelya_srl=0 probablya_srl=0 probably_nota_srl=0 definitely_nota_srl=0 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitelya=0 probablya=0 probably_nota=1 definitely_nota=0 definitelya_srl=0 probablya_srl=0 probably_nota_srl=1 definitely_nota_srl=0 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
prvalue, x(definitelya=0 probablya=0 probably_nota=0 definitely_nota=1 definitelya_srl=0 probablya_srl=0 probably_nota_srl=0 definitely_nota_srl=1 srl=1 polint=mean civic_duty=mean importance=mean knowledge=mean smoker=0 educ_low=0 educ_high=0 age=mean)
***************************************************************************************************************************************
***************************************************************************************************************************************
***************************************************************************************************************************************
*** Examining 'perhaps'-respondents with respect to aspects of involvement, using Variant A
* Value range from 0 to 1
compute polint1=(polint-1)/4.
compute civic_duty1=(civic_duty-1)/4.
compute importance1=(importance-1)/4.
compute knowledge1=knowledge/6.
* t-tests for independent samples
weight by Npersgew.
temp.
sel if perhapsa=1.
t-test groups srl (0,1) /var=polint1.
temp.
sel if perhapsa=1.
t-test groups srl (0,1) /var=civic_duty1.
temp.
sel if perhapsa=1.
t-test groups srl (0,1) /var=importance1.
temp.
sel if perhapsa=1.
t-test groups srl (0,1) /var=knowledge1.
***************************************************************************************************************************************
***************************************************************************************************************************************
****** for Variants B and C the same procedure applies, with the following thresholds:
* Variant B
recode zq04n zq13_1n zq13_2n zq13_3n zq13_4n zq13_5n zq13_6n zq13_7n zq13_8n zq13_9n zq13_10n zq24n zpid zpub zcancer (low thru 0.3=9999) (8.01 thru high = 9999) (else=copy)
into zq04h zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh.
* --> and so on
* Variant C
recode zq04n zq13_1n zq13_2n zq13_3n zq13_4n zq13_5n zq13_6n zq13_7n zq13_8n zq13_9n zq13_10n zq24n zpid zpub zcancer (low thru 0.09=9999) (5.01 thru high = 9999) (else=copy)
into zq04h zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh.
* --> and so on
***************************************************************************************************************************************
***************************************************************************************************************************************
*** Vote intention, Variant A
get file='C:\...\Volksentscheid_base.sav'.
* Keep only panel respondents
recode ndatum (100705 thru 100719=1) (else=0) into panel.
sel if panel=1.
* Exclude extreme outliers (reaction times over one minute)
recode zq05n zq13_1n zq13_2n zq13_3n zq13_4n zq13_5n zq13_6n zq13_7n zq13_8n zq13_9n zq13_10n zq24n zpid zpub zcancer (60.01 thru high = 9999) (else=copy).
sel if zq05n <> 9999.
sel if zq13_1n <> 9999.
sel if zq13_2n <> 9999.
sel if zq13_3n <> 9999.
sel if zq13_4n <> 9999.
sel if zq13_5n <> 9999.
sel if zq13_6n <> 9999.
sel if zq13_7n <> 9999.
sel if zq13_8n <> 9999.
sel if zq13_9n <> 9999.
sel if zq13_10n <> 9999.
sel if zq24n <> 9999.
sel if zpid <> 9999.
sel if zpub <> 9999.
sel if zcancer <> 9999.
* Calculate means and SDs
fre zq05n zq13_1n zq13_2n zq13_3n zq13_4n zq13_5n zq13_6n zq13_7n zq13_8n zq13_9n zq13_10n zq24n zpid zpub zcancer /sta mean stddev /format notable.
* upper limit
*zq05n: 23.66
*zq13_1n: 21.80
*zq13_2n: 18.81
*zq13_3n: 18.51
*zq13_4n: 10.48
*zq13_5n: 23.67
*zq13_6n: 16.93
*zq13_7n: 22.86
*zq13_8n: 15.05
*zq13_9n: 15.16
*zq13_10n: 19.33
*zq24n:25.29
*zpid: 19.91
*zpub: 14.61
*zcancer: 12.71
* Define valid range, +/- 2 SDs from MEAN (+ 0.01 for upper limit)
recode zq05n (23.67 thru high=9999) (else=copy) into zq05h.
recode zq13_1n (21.81 thru high=9999) (else=copy) into zq13_1h.
recode zq13_2n (18.82 thru high=9999) (else=copy) into zq13_2h.
recode zq13_3n (18.52 thru high=9999) (else=copy) into zq13_3h.
recode zq13_4n (10.49 thru high=9999) (else=copy) into zq13_4h.
recode zq13_5n (23.68 thru high=9999) (else=copy) into zq13_5h.
recode zq13_6n (16.94 thru high=9999) (else=copy) into zq13_6h.
recode zq13_7n (22.87 thru high=9999) (else=copy) into zq13_7h.
recode zq13_8n (15.06 thru high=9999) (else=copy) into zq13_8h.
recode zq13_9n (15.17 thru high=9999) (else=copy) into zq13_9h.
recode zq13_10n (19.34 thru high=9999) (else=copy) into zq13_10h.
recode zq24n (25.30 thru high=9999) (else=copy) into zq24h.
recode zpid (19.92 thru high=9999) (else=copy) into zpidh.
recode zpub (14.62 thru high=9999) (else=copy) into zpubh.
recode zcancer(12.72 thru high=9999) (else=copy) into zcancerh.
* Drop those invalid times for dependent variable
sel if zq05h <> 9999.
*Count missing values for filler latencies and drop if more than 6 missing values
count count_missing= zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh (9999).
recode count_missing (0 thru 6=0) (else=1) into number_missing.
fre number_missing.
sel if number_missing <> 1.
mis val zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh (9999).
fre zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh /sta range mean median skew stddev /format notable.
*** From now: Weighting active because e.g. Age, education might be correlated with reaction time
weight by npersgew.
* Construction of baseline speed with additive index (mean imputation)
compute basis=MEAN(zq13_1h, zq13_2h, zq13_3h, zq13_4h, zq13_5h, zq13_6h, zq13_7h, zq13_8h, zq13_9h, zq13_10h, zq24h, zpidh, zpubh, zcancerh).
* Descriptive statistics
fre basis zq05h /sta min max range mean median skew stddev /format notable.
corr zq05h with basis.
* Residual-Index
reg /dep=zq05h /enter=basis /residuals /save resid.
fre RES_1 /sta=mean median range skew stddev /format notable.
* Splitting Residual-Index at median, short vs. long response latency
if RES_1 > -1.81 srl=0.
if RES_1 <= -1.81 srl=1.
fre srl.
* Create vote choice, intention and interactions with srl
* reported vote choice
recode N03 (1=1) (2=0) (else=sysmis) into vote_pro.
* vote intention
recode Q05 (1=1) (2=0) (else=sysmis) into int_pro.
*Interaction with srl
compute int_pro_srl=int_pro*srl.
*** Saving these modifications as Stata-file for a simpler estimation of robust standard errors
SAVE TRANSLATE OUTFILE='C:\...\stata_voteA.dta'
/TYPE=STATA
/VERSION=8
/EDITION=SE
/MAP
/REPLACE.
***************************************************************************************************************************************
*** Stata syntax
* Logit models with and without latencies
logit vote_pro int_pro polint importance knowledge smoker educ_low educ_high age [pweight=Npersgew]
logit vote_pro int_pro int_pro_srl srl polint importance knowledge smoker educ_low educ_high age [pweight=Npersgew]
***************************************************************************************************************************************
****** for Variants B and C the same procedure applies, with the following thresholds:
* Variant B
recode zq05n zq13_1n zq13_2n zq13_3n zq13_4n zq13_5n zq13_6n zq13_7n zq13_8n zq13_9n zq13_10n zq24n zpid zpub zcancer (low thru 0.3=9999) (8.01 thru high = 9999) (else=copy)
into zq05h zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh.
* --> and so on
* Variant C
recode zq05n zq13_1n zq13_2n zq13_3n zq13_4n zq13_5n zq13_6n zq13_7n zq13_8n zq13_9n zq13_10n zq24n zpid zpub zcancer (low thru 0.09=9999) (5.01 thru high = 9999) (else=copy)
into zq05h zq13_1h zq13_2h zq13_3h zq13_4h zq13_5h zq13_6h zq13_7h zq13_8h zq13_9h zq13_10h zq24h zpidh zpubh zcancerh.
* --> and so on
***************************************************************************************************************************************
